// The following program demonstrates the wakeup on pin feature. 
// Setting P04 low puts the nRF24LE1 into deep sleep, and setting P06 low wakes it up again (NOTE: on the 48-pin nRF24LE1, P26 is used instead of P06)
// LED0 and LED1 indicate the state of the nRF24LE1:
//  0        0   - nRF24LE1 is in deep sleep mode
//  1        0   - nRF24LE1 is active after a power on reset (typically just after programming)
//  1        1   - nRF24LE1 is active after being woken by pin
 
#include <Nordic\reg24le1.h>
#include <stdint.h>

#define LED0               P00
#define LED1               P01
#define BUTTON_ENTER_SLEEP !P04

// Disconnect all the GPIO's to avoid excessive deep sleep current caused by floating pins.
void disconnectGPIO()
{
  P0CON = 0x70;
  P0CON = 0x71;
  P0CON = 0x72;
  P0CON = 0x73;
  P0CON = 0x74;
  P0CON = 0x75;
  //P0CON = 0x76;    // P06 must not be disconnected as it is required to wake up the nRF24LE1
  P0CON = 0x77;

  P1CON = 0x70;
  P1CON = 0x71;
  P1CON = 0x72;
  P1CON = 0x73;
  P1CON = 0x74;
  P1CON = 0x75;
  P1CON = 0x76;
  P1CON = 0x77;

  P2CON = 0x70;
  P2CON = 0x71;
  P2CON = 0x72;
  P2CON = 0x73;
  P2CON = 0x74;
  P2CON = 0x75;
  P2CON = 0x76;     // If the 48-pin nRF24LE1 is used this line must be commented out instead of the one above   
  P2CON = 0x77;

  P3CON = 0x70;
  P3CON = 0x71;
  P3CON = 0x72;
  P3CON = 0x73;
  P3CON = 0x74;
  P3CON = 0x75;
  P3CON = 0x76;
}

void main()
{
  // Open GPIO latches in case they were previously locked.
  OPMCON = 0x00;

  // Set P00 and P01 to output, the other pins to input
  P0DIR = 0xFC;

  LED0 = 1;
  LED1 = 0;

  if( PWRDWN & 0x80 )
  {
    // Wakeup from pin.
    LED1 = 1;
  }

  while(1)
  {
    if( BUTTON_ENTER_SLEEP )
    {
      LED0 = 0;
      LED1 = 0;

      // Disconnect all the GPIO's to avoid excessive deep sleep current caused by floating pins.
      disconnectGPIO();
      
      // Enabled wakeup on pin on P06 (24-pin or 32-pin LE1) or P26 (48-pin LE1).
      WUOPC0 = 0x40;

      // Inverse wakeup on pin polarity on selected GPIO's (P06 on 24-pin LE1. P06, P12 and P14 on 32-pin LE1. P22 and P26 on 48-pin LE1).
      OPMCON |= 0x04;

      // Lock GPIO latches. 
      OPMCON |= 0x02;

      // Enter deep sleep.
      PWRDWN = 0x01;
    }
  }
}